'use strict'

const fs = require('fs')
const tmplconv = require('tmplconv')
const path = require('path')
const co = require('co')
const findout = require('findout')

let tmpl = path.resolve(__dirname, '../asset/tmpl')

/** @lends apemanInit */
function apemanInit (options = {}) {
  let dest = options.dirname || process.cwd()
  let silent = options.silent || false

  return co(function * () {
    let exists = yield new Promise((resolve) =>
      fs.exists(dest + '/Apemanfile.js', (exists) => resolve(exists))
    )
    let fail = exists && !options.force
    if (fail) {
      throw new Error('Already initialized. Use -f option to force init.')
    }
    let pkg = findout.resolve('package.json', { safe: true }) || options.pkg || './package.json'
    pkg = path.resolve(pkg)
    let env = path.join(path.dirname(pkg), 'env')

    return tmplconv.render(tmpl, dest, {
      mode: '644',
      silent: silent,
      pattern: [
        'Apemanfile.js.tmpl'
      ],
      data: {
        pkg: _relativePath(dest, pkg),
        env: _relativePath(dest, env)
      }
    })
  })
}

function _relativePath (base, filename) {
  let relative = path.relative(base, filename)
  if (relative === path.basename(filename)) {
    return './' + relative
  }
  return relative
}

module.exports = apemanInit
